Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(12)

Unified Diff: remoting/client/software_video_renderer.h

Issue 2113523007: More cleanups in FrameStats (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: fix android Created 4 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « remoting/client/plugin/pepper_video_renderer_3d.cc ('k') | remoting/client/software_video_renderer.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: remoting/client/software_video_renderer.h
diff --git a/remoting/client/software_video_renderer.h b/remoting/client/software_video_renderer.h
index e4bd82184f43944756277a38439af598506118e8..2172500b105162cadb61a680423b7841e8ffa722 100644
--- a/remoting/client/software_video_renderer.h
+++ b/remoting/client/software_video_renderer.h
@@ -32,7 +32,7 @@ class VideoDecoder;
namespace protocol {
class FrameConsumer;
struct FrameStats;
-class PerformanceTracker;
+class FrameStatsConsumer;
} // namespace protocol
// Implementation of VideoRenderer interface that decodes frame on CPU (on a
@@ -42,27 +42,28 @@ class SoftwareVideoRenderer : public protocol::VideoRenderer,
public:
// The renderer can be created on any thread but afterwards all methods must
// be called on the same thread.
- SoftwareVideoRenderer(protocol::FrameConsumer* consumer);
+ explicit SoftwareVideoRenderer(protocol::FrameConsumer* consumer);
// Deprecated constructor. TODO(yuweih): remove.
// Constructs the renderer and initializes it immediately. Caller should not
// call Initialize() after using this constructor.
// All methods must be called on the same thread the renderer is created. The
// |decode_task_runner_| is used to decode the video packets. |perf_tracker|
// must outlive the renderer. |perf_tracker| may be nullptr, performance
// tracking is disabled in that case.
SoftwareVideoRenderer(
scoped_refptr<base::SingleThreadTaskRunner> decode_task_runner,
protocol::FrameConsumer* consumer,
- protocol::PerformanceTracker* perf_tracker);
+ protocol::FrameStatsConsumer* stats_consumer);
~SoftwareVideoRenderer() override;
// VideoRenderer interface.
bool Initialize(const ClientContext& client_context,
- protocol::PerformanceTracker* perf_tracker) override;
+ protocol::FrameStatsConsumer* stats_consumer) override;
void OnSessionConfig(const protocol::SessionConfig& config) override;
protocol::VideoStub* GetVideoStub() override;
protocol::FrameConsumer* GetFrameConsumer() override;
+ protocol::FrameStatsConsumer* GetFrameStatsConsumer() override;
// protocol::VideoStub interface.
void ProcessVideoPacket(std::unique_ptr<VideoPacket> packet,
@@ -76,8 +77,8 @@ class SoftwareVideoRenderer : public protocol::VideoRenderer,
const base::Closure& done);
scoped_refptr<base::SingleThreadTaskRunner> decode_task_runner_;
- protocol::FrameConsumer* consumer_;
- protocol::PerformanceTracker* perf_tracker_ = nullptr;
+ protocol::FrameConsumer* const consumer_;
+ protocol::FrameStatsConsumer* stats_consumer_ = nullptr;
std::unique_ptr<VideoDecoder> decoder_;
« no previous file with comments | « remoting/client/plugin/pepper_video_renderer_3d.cc ('k') | remoting/client/software_video_renderer.cc » ('j') | no next file with comments »
@@ -42,27 +42,28 @@ class SoftwareVideoRenderer : public protocol::VideoRenderer,
// call Initialize() after using this constructor.
// All methods must be called on the same thread the renderer is created. The
- // |decode_task_runner_| is used to decode the video packets. |perf_tracker|
- // must outlive the renderer. |perf_tracker| may be nullptr, performance
- // tracking is disabled in that case.
+ // |decode_task_runner_| is used to decode the video packets. |consumer| and
+ // |stats_consumer| must outlive the renderer. |stats_consumer| may be
+ // nullptr, performance tracking is disabled in that case.
SoftwareVideoRenderer(
scoped_refptr<base::SingleThreadTaskRunner> decode_task_runner,

Powered by Google App Engine
This is Rietveld 408576698